import { KhayyamNS } from 'omar-khayyam';
export declare namespace DatedNS {
    namespace LocaleNS {
        const Locales: readonly ["en", "fa", "ar"];
        type Locales = (typeof Locales)[number];
        interface Name {
            long: string;
            short: string;
            narrow: string;
            index: number;
        }
        interface Locale {
            months: Name[];
            weeks: Name[];
            formats: FormatNS.Defaults;
            meridiem: {
                AM: Omit<Name, 'narrow'>;
                PM: Omit<Name, 'narrow'>;
            };
        }
    }
    namespace TimeNS {
        type Time = Pick<DateNS.Dated, 'hour' | 'minute' | 'second' | 'millisecond'>;
    }
    namespace DateNS {
        type Durations = (typeof Durations)[number];
        const Durations: readonly ["years", "months", "weeks", "days", "hours", "minutes", "seconds", "milliseconds"];
        namespace Now {
            type Overload1 = (value: number | string) => Date;
            type Overload2 = (year: number, month: number, day?: number, hours?: number, minutes?: number, seconds?: number, ms?: number) => Date;
        }
        interface Dated {
            year: number;
            month: number;
            day: number;
            weekDay: number;
            hour: number;
            minute: number;
            second: number;
            millisecond: number;
        }
        type DateOnly = Pick<Dated, 'year' | 'month' | 'day' | 'weekDay'>;
        type PureDateOnly = Omit<DateOnly, 'weekDay'>;
        type DateInput = Partial<Dated> | number | string | Date | [
            string | number,
            string | number,
            string | number,
            string | number,
            string | number,
            string | number,
            string | number
        ];
    }
    namespace FormatNS {
        type Format = (format?: string | ((formats: Defaults) => string)) => string;
        enum tokens {
            $yyyy = "$yyyy",
            $yy = "$yy",
            $mm = "$mm",
            $m = "$m",
            $MMM = "$MMM",
            $MM = "$MM",
            $M = "$M",
            $dd = "$dd",
            $d = "$d",
            $DDD = "$DDD",
            $DD = "$DD",
            $D = "$D",
            $hh = "$hh",
            $h = "$h",
            $ll = "$ll",
            $l = "$l",
            $ss = "$ss",
            $s = "$s",
            $ee = "$ee",
            $e = "$e"
        }
        interface Defaults {
            full: string;
            fullTimed: string;
            slashed: string;
            slashedTimed: string;
            dashed: string;
            dashedTimed: string;
            timeOnly: string;
        }
    }
    namespace EventsNS {
        type EventsByCalendar = {
            [key in KhayyamNS.Calendars]: EventsNS.Type[];
        };
        type Translation = {
            [locale in LocaleNS.Locales]: string;
        };
        interface Type extends Translation {
            day: number;
            month: number;
            isHoliday?: boolean;
            ref?: string;
        }
        interface Collection {
            [month: number]: {
                [day: number]: Type[];
            };
        }
    }
}
